@@ -1,34 +1,20 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "bondwidget.h"
-#include "ui_bond.h"
 #include "connectioneditordialog.h"
 #include "debug.h"
+#include "ui_bond.h"
 
 #include <QDBusPendingReply>
 
-#include <NetworkManagerQt/GenericTypes>
 #include <NetworkManagerQt/Connection>
-#include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/ConnectionSettings>
+#include <NetworkManagerQt/GenericTypes>
+#include <NetworkManagerQt/Settings>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -36,18 +22,17 @@
 #define NM_SETTING_BOND_OPTION_MII_MONITOR "mii"
 #define NM_SETTING_BOND_OPTION_ARP_MONITOR "arp"
 
-BondWidget::BondWidget(const QString & masterUuid, const QString &masterId,
-                       const NetworkManager::Setting::Ptr &setting, QWidget* parent, Qt::WindowFlags f):
-    SettingWidget(setting, parent, f),
-    m_uuid(masterUuid),
-    m_id(masterId),
-    m_ui(new Ui::BondWidget)
+BondWidget::BondWidget(const QString &masterUuid, const QString &masterId, const NetworkManager::Setting::Ptr &setting, QWidget *parent, Qt::WindowFlags f)
+    : SettingWidget(setting, parent, f)
+    , m_uuid(masterUuid)
+    , m_id(masterId)
+    , m_ui(new Ui::BondWidget)
 {
     m_ui->setupUi(this);
 
     // Action buttons and menu
     m_menu = new QMenu(this);
-    QAction * action = new QAction(i18n("Ethernet"), this);
+    QAction *action = new QAction(i18n("Ethernet"), this);
     action->setData(NetworkManager::ConnectionSettings::Wired);
     m_menu->addAction(action);
     action = new QAction(i18n("InfiniBand"), this);
@@ -173,27 +158,26 @@ void BondWidget::addBond(QAction *action)
     qCDebug(PLASMA_NM) << "Slave type:" << type();
 
     NetworkManager::ConnectionSettings::ConnectionType connectionType = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toInt());
-    NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(connectionType));
+    NetworkManager::ConnectionSettings::Ptr connectionSettings =
+        NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(connectionType));
     connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
     connectionSettings->setMaster(m_uuid);
     connectionSettings->setSlaveType(type());
     connectionSettings->setAutoconnect(false);
 
     QPointer<ConnectionEditorDialog> bondEditor = new ConnectionEditorDialog(connectionSettings);
-    connect(bondEditor.data(), &ConnectionEditorDialog::accepted,
-            [bondEditor, this] () {
-                qCDebug(PLASMA_NM) << "Saving slave connection";
-                // qCDebug(PLASMA_NM) << bondEditor->setting();
-                QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bondEditor->setting());
-                QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
-                connect(watcher, &QDBusPendingCallWatcher::finished, this, &BondWidget::bondAddComplete);
-            });
-    connect(bondEditor.data(), &ConnectionEditorDialog::finished,
-            [bondEditor] () {
-                if (bondEditor) {
-                    bondEditor->deleteLater();
-                }
-            });
+    connect(bondEditor.data(), &ConnectionEditorDialog::accepted, [bondEditor, this]() {
+        qCDebug(PLASMA_NM) << "Saving slave connection";
+        // qCDebug(PLASMA_NM) << bondEditor->setting();
+        QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bondEditor->setting());
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, &BondWidget::bondAddComplete);
+    });
+    connect(bondEditor.data(), &ConnectionEditorDialog::finished, [bondEditor]() {
+        if (bondEditor) {
+            bondEditor->deleteLater();
+        }
+    });
     bondEditor->setModal(true);
     bondEditor->show();
 }
@@ -206,7 +190,7 @@ void BondWidget::currentBondChanged(QListWidgetItem *current, QListWidgetItem *p
     m_ui->btnDelete->setEnabled(current);
 }
 
-void BondWidget::bondAddComplete(QDBusPendingCallWatcher * watcher)
+void BondWidget::bondAddComplete(QDBusPendingCallWatcher *watcher)
 {
     QDBusPendingReply<QDBusObjectPath> reply = *watcher;
 
@@ -214,8 +198,9 @@ void BondWidget::bondAddComplete(QDBusPendingCallWatcher * watcher)
         // find the slave connection with matching UUID
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(reply.value().path());
         if (connection && connection->settings()->master() == m_uuid) {
-            const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem * slaveItem = new QListWidgetItem(label, m_ui->bonds);
+            const QString label =
+                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
+            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->bonds);
             slaveItem->setData(Qt::UserRole, connection->uuid());
             slotWidgetChanged();
         }
@@ -226,7 +211,7 @@ void BondWidget::bondAddComplete(QDBusPendingCallWatcher * watcher)
 
 void BondWidget::editBond()
 {
-    QListWidgetItem * currentItem = m_ui->bonds->currentItem();
+    QListWidgetItem *currentItem = m_ui->bonds->currentItem();
     if (!currentItem)
         return;
 
@@ -236,17 +221,15 @@ void BondWidget::editBond()
     if (connection) {
         // qCDebug(PLASMA_NM) << "Editing bonded connection" << currentItem->text() << uuid;
         QPointer<ConnectionEditorDialog> bondEditor = new ConnectionEditorDialog(connection->settings());
-        connect(bondEditor.data(), &ConnectionEditorDialog::accepted,
-                [connection, bondEditor, this] () {
-                    connection->update(bondEditor->setting());
-                    connect(connection.data(), &NetworkManager::Connection::updated, this, &BondWidget::populateBonds);
-                });
-        connect(bondEditor.data(), &ConnectionEditorDialog::finished,
-                [bondEditor] () {
-                    if (bondEditor) {
-                        bondEditor->deleteLater();
-                    }
-                });
+        connect(bondEditor.data(), &ConnectionEditorDialog::accepted, [connection, bondEditor, this]() {
+            connection->update(bondEditor->setting());
+            connect(connection.data(), &NetworkManager::Connection::updated, this, &BondWidget::populateBonds);
+        });
+        connect(bondEditor.data(), &ConnectionEditorDialog::finished, [bondEditor]() {
+            if (bondEditor) {
+                bondEditor->deleteLater();
+            }
+        });
         bondEditor->setModal(true);
         bondEditor->show();
     }
@@ -254,7 +237,7 @@ void BondWidget::editBond()
 
 void BondWidget::deleteBond()
 {
-    QListWidgetItem * currentItem = m_ui->bonds->currentItem();
+    QListWidgetItem *currentItem = m_ui->bonds->currentItem();
     if (!currentItem)
         return;
 
@@ -263,9 +246,14 @@ void BondWidget::deleteBond()
 
     if (connection) {
         // qCDebug(PLASMA_NM) << "About to delete bonded connection" << currentItem->text() << uuid;
-        if (KMessageBox::questionYesNo(this, i18n("Do you want to remove the connection '%1'?", connection->name()), i18n("Remove Connection"),
-                                       KStandardGuiItem::remove(), KStandardGuiItem::no(), QString(), KMessageBox::Dangerous)
-                == KMessageBox::Yes) {
+        if (KMessageBox::questionYesNo(this,
+                                       i18n("Do you want to remove the connection '%1'?", connection->name()),
+                                       i18n("Remove Connection"),
+                                       KStandardGuiItem::remove(),
+                                       KStandardGuiItem::no(),
+                                       QString(),
+                                       KMessageBox::Dangerous)
+            == KMessageBox::Yes) {
             connection->remove();
             delete currentItem;
             slotWidgetChanged();
@@ -285,8 +273,9 @@ void BondWidget::populateBonds()
         bool isSlave = ((master == m_uuid) || // by-uuid
                         (!m_id.isEmpty() && master == m_id)); // by-name
         if (isSlave && (settings->slaveType() == type())) {
-            const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem * slaveItem = new QListWidgetItem(label, m_ui->bonds);
+            const QString label =
+                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
+            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->bonds);
             slaveItem->setData(Qt::UserRole, connection->uuid());
         }
     }
