@@ -1,27 +1,13 @@
 /*
-    Copyright (c) 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "security802-1x.h"
-#include "ui_802-1x.h"
 #include "editlistdialog.h"
 #include "listvalidator.h"
+#include "ui_802-1x.h"
 
 #include <KAcceleratorManager>
 #include <KLocalizedString>
@@ -108,7 +94,9 @@ Security8021x::Security8021x(const NetworkManager::Setting::Ptr &setting, bool w
     KAcceleratorManager::manage(this);
     connect(m_ui->stackedWidget, &QStackedWidget::currentChanged, this, &Security8021x::currentAuthChanged);
 
-    altSubjectValidator = new QRegExpValidator(QRegExp(QLatin1String("^(DNS:[a-zA-Z0-9_-]+\\.[a-zA-Z0-9_.-]+|EMAIL:[a-zA-Z0-9._-]+@[a-zA-Z0-9_-]+\\.[a-zA-Z0-9_.-]+|URI:[a-zA-Z0-9.+-]+:.+|)$")), this);
+    altSubjectValidator = new QRegExpValidator(
+        QRegExp(QLatin1String("^(DNS:[a-zA-Z0-9_-]+\\.[a-zA-Z0-9_.-]+|EMAIL:[a-zA-Z0-9._-]+@[a-zA-Z0-9_-]+\\.[a-zA-Z0-9_.-]+|URI:[a-zA-Z0-9.+-]+:.+|)$")),
+        this);
     serversValidator = new QRegExpValidator(QRegExp(QLatin1String("^[a-zA-Z0-9_-]+\\.[a-zA-Z0-9_.-]+$")), this);
 
     ListValidator *altSubjectListValidator = new ListValidator(this);
@@ -158,7 +146,7 @@ void Security8021x::loadConfig(const NetworkManager::Setting::Ptr &setting)
         m_ui->leTlsAlternativeSubjectMatches->setText(securitySetting->altSubjectMatches().join(QLatin1String(", ")));
         for (const QString &match : securitySetting->altSubjectMatches()) {
             if (match.startsWith(QLatin1String("DNS:"))) {
-                servers.append(match.right(match.length()-4));
+                servers.append(match.right(match.length() - 4));
             }
         }
         m_ui->leTlsConnectToServers->setText(servers.join(QLatin1String(", ")));
@@ -295,7 +283,7 @@ QVariantMap Security8021x::setting() const
     NetworkManager::Security8021xSetting setting;
 
     NetworkManager::Security8021xSetting::EapMethod method =
-            static_cast<NetworkManager::Security8021xSetting::EapMethod>(m_ui->auth->itemData(m_ui->auth->currentIndex()).toInt());
+        static_cast<NetworkManager::Security8021xSetting::EapMethod>(m_ui->auth->itemData(m_ui->auth->currentIndex()).toInt());
 
     setting.setEapMethods(QList<NetworkManager::Security8021xSetting::EapMethod>() << method);
 
@@ -332,8 +320,8 @@ QVariantMap Security8021x::setting() const
             setting.setCaCertificate(m_ui->tlsCACert->url().toString().toUtf8().append('\0'));
         }
 
-        QStringList altsubjectmatches = m_ui->leTlsAlternativeSubjectMatches->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), QString::SkipEmptyParts);
-        for (const QString &match : m_ui->leTlsConnectToServers->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), QString::SkipEmptyParts)) {
+        QStringList altsubjectmatches = m_ui->leTlsAlternativeSubjectMatches->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), Qt::SkipEmptyParts);
+        for (const QString &match : m_ui->leTlsConnectToServers->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), Qt::SkipEmptyParts)) {
             const QString tempstr = QLatin1String("DNS:") + match;
             if (!altsubjectmatches.contains(tempstr)) {
                 altsubjectmatches.append(tempstr);
@@ -523,21 +511,21 @@ void Security8021x::altSubjectMatchesButtonClicked()
 {
     QPointer<EditListDialog> editor = new EditListDialog(this);
 
-    editor->setItems(m_ui->leTlsSubjectMatch->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), QString::SkipEmptyParts));
+    editor->setItems(m_ui->leTlsSubjectMatch->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), Qt::SkipEmptyParts));
     editor->setWindowTitle(i18n("Alternative Subject Matches"));
-    editor->setToolTip(i18n("<qt>This entry must be one of:<ul><li>DNS: &lt;name or ip address&gt;</li><li>EMAIL: &lt;email&gt;</li><li>URI: &lt;uri, e.g. https://www.kde.org&gt;</li></ul></qt>"));
+    editor->setToolTip(
+        i18n("<qt>This entry must be one of:<ul><li>DNS: &lt;name or ip address&gt;</li><li>EMAIL: &lt;email&gt;</li><li>URI: &lt;uri, e.g. "
+             "https://www.kde.org&gt;</li></ul></qt>"));
     editor->setValidator(altSubjectValidator);
 
-    connect(editor.data(), &QDialog::accepted,
-            [editor, this] () {
-                m_ui->leTlsSubjectMatch->setText(editor->items().join(QLatin1String(", ")));
-            });
-    connect(editor.data(), &QDialog::finished,
-            [editor] () {
-                if (editor) {
-                    editor->deleteLater();
-                }
-            });
+    connect(editor.data(), &QDialog::accepted, [editor, this]() {
+        m_ui->leTlsSubjectMatch->setText(editor->items().join(QLatin1String(", ")));
+    });
+    connect(editor.data(), &QDialog::finished, [editor]() {
+        if (editor) {
+            editor->deleteLater();
+        }
+    });
     editor->setModal(true);
     editor->show();
 }
@@ -546,20 +534,18 @@ void Security8021x::connectToServersButtonClicked()
 {
     QPointer<EditListDialog> editor = new EditListDialog(this);
 
-    editor->setItems(m_ui->leTlsConnectToServers->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), QString::SkipEmptyParts));
+    editor->setItems(m_ui->leTlsConnectToServers->text().remove(QLatin1Char(' ')).split(QLatin1Char(','), Qt::SkipEmptyParts));
     editor->setWindowTitle(i18n("Connect to these servers only"));
     editor->setValidator(serversValidator);
 
-    connect(editor.data(), &QDialog::accepted,
-            [editor, this] () {
-                m_ui->leTlsConnectToServers->setText(editor->items().join(QLatin1String(", ")));
-            });
-    connect(editor.data(), &QDialog::finished,
-            [editor] () {
-                if (editor) {
-                    editor->deleteLater();
-                }
-            });
+    connect(editor.data(), &QDialog::accepted, [editor, this]() {
+        m_ui->leTlsConnectToServers->setText(editor->items().join(QLatin1String(", ")));
+    });
+    connect(editor.data(), &QDialog::finished, [editor]() {
+        if (editor) {
+            editor->deleteLater();
+        }
+    });
     editor->setModal(true);
     editor->show();
 }
@@ -567,10 +553,11 @@ void Security8021x::connectToServersButtonClicked()
 bool Security8021x::isValid() const
 {
     NetworkManager::Security8021xSetting::EapMethod method =
-            static_cast<NetworkManager::Security8021xSetting::EapMethod>(m_ui->auth->itemData(m_ui->auth->currentIndex()).toInt());
+        static_cast<NetworkManager::Security8021xSetting::EapMethod>(m_ui->auth->itemData(m_ui->auth->currentIndex()).toInt());
 
     if (method == NetworkManager::Security8021xSetting::EapMethodMd5) {
-        return !m_ui->md5UserName->text().isEmpty() && (!m_ui->md5Password->text().isEmpty() || m_ui->md5Password->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->md5UserName->text().isEmpty()
+            && (!m_ui->md5Password->text().isEmpty() || m_ui->md5Password->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodTls) {
         if (m_ui->tlsIdentity->text().isEmpty()) {
             return false;
@@ -614,18 +601,23 @@ bool Security8021x::isValid() const
         // TODO Try other formats (DER - mainly used in Windows)
         // TODO Validate other certificates??
     } else if (method == NetworkManager::Security8021xSetting::EapMethodLeap) {
-        return !m_ui->leapUsername->text().isEmpty() && (!m_ui->leapPassword->text().isEmpty() || m_ui->leapPassword->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->leapUsername->text().isEmpty()
+            && (!m_ui->leapPassword->text().isEmpty() || m_ui->leapPassword->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodPwd) {
-        return !m_ui->pwdUsername->text().isEmpty() && (!m_ui->pwdPassword->text().isEmpty() || m_ui->pwdPassword->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->pwdUsername->text().isEmpty()
+            && (!m_ui->pwdPassword->text().isEmpty() || m_ui->pwdPassword->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodFast) {
         if (!m_ui->fastAllowPacProvisioning->isChecked() && !m_ui->pacFile->url().isValid()) {
             return false;
         }
-        return !m_ui->fastUsername->text().isEmpty() && (!m_ui->fastPassword->text().isEmpty()  || m_ui->fastPassword->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->fastUsername->text().isEmpty()
+            && (!m_ui->fastPassword->text().isEmpty() || m_ui->fastPassword->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodTtls) {
-         return !m_ui->ttlsUsername->text().isEmpty() && (!m_ui->ttlsPassword->text().isEmpty() || m_ui->ttlsPassword->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->ttlsUsername->text().isEmpty()
+            && (!m_ui->ttlsPassword->text().isEmpty() || m_ui->ttlsPassword->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodPeap) {
-         return !m_ui->peapUsername->text().isEmpty() && (!m_ui->peapPassword->text().isEmpty() || m_ui->peapPassword->passwordOption() == PasswordField::AlwaysAsk);
+        return !m_ui->peapUsername->text().isEmpty()
+            && (!m_ui->peapPassword->text().isEmpty() || m_ui->peapPassword->passwordOption() == PasswordField::AlwaysAsk);
     }
 
     return true;
