@@ -1,42 +1,29 @@
 /*
-Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
+    SPDX-FileCopyrightText: 2011 Ilia Kats <ilia-kats@gmx.net>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+#include <QNetworkAddressEntry>
 #include <QStandardItem>
 #include <QStandardItemModel>
-#include <QNetworkAddressEntry>
 
 #include <KAcceleratorManager>
 #include <KLocalizedString>
 
 #include "ui_ipv6routes.h"
 
-#include "ipv6delegate.h"
 #include "intdelegate.h"
+#include "ipv6delegate.h"
 #include "ipv6routeswidget.h"
 
 class IpV6RoutesWidget::Private
 {
 public:
-    Private() : model(0,4)
+    Private()
+        : model(0, 4)
     {
-        QStandardItem * headerItem = new QStandardItem(i18nc("Header text for IPv6 address", "Address"));
+        QStandardItem *headerItem = new QStandardItem(i18nc("Header text for IPv6 address", "Address"));
         model.setHorizontalHeaderItem(0, headerItem);
         headerItem = new QStandardItem(i18nc("Header text for IPv6 netmask", "Netmask"));
         model.setHorizontalHeaderItem(1, headerItem);
@@ -49,15 +36,16 @@ public:
     QStandardItemModel model;
 };
 
-IpV6RoutesWidget::IpV6RoutesWidget(QWidget * parent)
-    : QDialog(parent), d(new IpV6RoutesWidget::Private())
+IpV6RoutesWidget::IpV6RoutesWidget(QWidget *parent)
+    : QDialog(parent)
+    , d(new IpV6RoutesWidget::Private())
 {
     d->ui.setupUi(this);
     d->ui.tableViewAddresses->setModel(&d->model);
     d->ui.tableViewAddresses->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 
     IpV6Delegate *ipDelegate = new IpV6Delegate(this);
-    IntDelegate *netmaskDelegate = new IntDelegate(0,128,this);
+    IntDelegate *netmaskDelegate = new IntDelegate(0, 128, this);
     IntDelegate *metricDelegate = new IntDelegate(this);
     d->ui.tableViewAddresses->setItemDelegateForColumn(0, ipDelegate);
     d->ui.tableViewAddresses->setItemDelegateForColumn(1, netmaskDelegate);
@@ -69,7 +57,6 @@ IpV6RoutesWidget::IpV6RoutesWidget(QWidget * parent)
 
     connect(d->ui.tableViewAddresses->selectionModel(), &QItemSelectionModel::selectionChanged, this, &IpV6RoutesWidget::selectionChanged);
 
-
     connect(&d->model, &QStandardItemModel::itemChanged, this, &IpV6RoutesWidget::tableViewItemChanged);
 
     connect(d->ui.buttonBox, &QDialogButtonBox::accepted, this, &IpV6RoutesWidget::accept);
@@ -112,12 +99,12 @@ void IpV6RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
 {
     d->model.removeRows(0, d->model.rowCount());
     for (const NetworkManager::IpRoute &route : list) {
-        QList<QStandardItem *> item;
-        // qCDebug(PLASMA_NM) << route.ip();
-        item << new QStandardItem(route.ip().toString())
-             << new QStandardItem(QString::number(route.prefixLength(), 10))
-             << new QStandardItem(route.nextHop().toString())
-             << new QStandardItem(QString::number(route.metric(), 10));
+        QList<QStandardItem *> item{
+            new QStandardItem(route.ip().toString()),
+            new QStandardItem(QString::number(route.prefixLength(), 10)),
+            new QStandardItem(route.nextHop().toString()),
+            new QStandardItem(QString::number(route.metric(), 10)),
+        };
 
         d->model.appendRow(item);
     }
@@ -129,7 +116,7 @@ QList<NetworkManager::IpRoute> IpV6RoutesWidget::routes()
 
     for (int i = 0, rowCount = d->model.rowCount(); i < rowCount; i++) {
         NetworkManager::IpRoute route;
-        QStandardItem *item = d->model.item(i,0);
+        QStandardItem *item = d->model.item(i, 0);
         if (item) {
             route.setIp(QHostAddress(item->text()));
         }
@@ -153,15 +140,14 @@ QList<NetworkManager::IpRoute> IpV6RoutesWidget::routes()
 
 void IpV6RoutesWidget::addRoute()
 {
-    QList<QStandardItem *> item;
-    item << new QStandardItem << new QStandardItem << new QStandardItem;
+    QList<QStandardItem *> item{new QStandardItem, new QStandardItem, new QStandardItem};
     d->model.appendRow(item);
 
     const int rowCount = d->model.rowCount();
     if (rowCount > 0) {
         d->ui.tableViewAddresses->selectRow(rowCount - 1);
 
-        QItemSelectionModel * selectionModel = d->ui.tableViewAddresses->selectionModel();
+        QItemSelectionModel *selectionModel = d->ui.tableViewAddresses->selectionModel();
         QModelIndexList list = selectionModel->selectedIndexes();
         if (list.size()) {
             // QTableView is configured to select only rows.
@@ -173,7 +159,7 @@ void IpV6RoutesWidget::addRoute()
 
 void IpV6RoutesWidget::removeRoute()
 {
-    QItemSelectionModel * selectionModel = d->ui.tableViewAddresses->selectionModel();
+    QItemSelectionModel *selectionModel = d->ui.tableViewAddresses->selectionModel();
     if (selectionModel->hasSelection()) {
         QModelIndexList indexes = selectionModel->selectedIndexes();
         d->model.takeRow(indexes[0].row());
@@ -181,7 +167,7 @@ void IpV6RoutesWidget::removeRoute()
     d->ui.pushButtonRemove->setEnabled(false);
 }
 
-void IpV6RoutesWidget::selectionChanged(const QItemSelection & selected)
+void IpV6RoutesWidget::selectionChanged(const QItemSelection &selected)
 {
     // qCDebug(PLASMA_NM) << "selectionChanged";
     d->ui.pushButtonRemove->setEnabled(!selected.isEmpty());
@@ -204,7 +190,7 @@ void IpV6RoutesWidget::tableViewItemChanged(QStandardItem *item)
             QHostAddress addr(item->text());
             quint32 netmask = suggestNetmask(addr.toIPv6Address());
             if (netmask) {
-                netmaskItem->setText(QString::number(netmask,10));
+                netmaskItem->setText(QString::number(netmask, 10));
             }
         }
     }
