@@ -1,22 +1,8 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "ssidcombobox.h"
@@ -27,13 +13,13 @@
 
 #include <KLocalizedString>
 
-bool signalCompare(const NetworkManager::WirelessNetwork::Ptr & one, const NetworkManager::WirelessNetwork::Ptr & two)
+bool signalCompare(const NetworkManager::WirelessNetwork::Ptr &one, const NetworkManager::WirelessNetwork::Ptr &two)
 {
     return one->signalStrength() > two->signalStrength();
 }
 
-SsidComboBox::SsidComboBox(QWidget *parent) :
-    KComboBox(parent)
+SsidComboBox::SsidComboBox(QWidget *parent)
+    : KComboBox(parent)
 {
     setEditable(true);
     setInsertPolicy(QComboBox::NoInsert);
@@ -134,12 +120,23 @@ void SsidComboBox::addSsidsToCombo(const QList<NetworkManager::WirelessNetwork::
                 }
                 empty = false;
 
-                NetworkManager::WirelessSecurityType security = NetworkManager::findBestWirelessSecurity(wifiDev->wirelessCapabilities(), true, (wifiDev->mode() == NetworkManager::WirelessDevice::Adhoc), accessPoint->capabilities(), accessPoint->wpaFlags(), accessPoint->rsnFlags());
+                NetworkManager::WirelessSecurityType security =
+                    NetworkManager::findBestWirelessSecurity(wifiDev->wirelessCapabilities(),
+                                                             true,
+                                                             (wifiDev->mode() == NetworkManager::WirelessDevice::Adhoc),
+                                                             accessPoint->capabilities(),
+                                                             accessPoint->wpaFlags(),
+                                                             accessPoint->rsnFlags());
                 if (security != NetworkManager::UnknownSecurity && security != NetworkManager::NoneSecurity) {
-                    const QString text = i18n("%1 (%2%)\nSecurity: %3\nFrequency: %4 Mhz", accessPoint->ssid(), network->signalStrength(), UiUtils::labelFromWirelessSecurity(security), accessPoint->frequency());
+                    const QString text = i18n("%1 (%2%)\nSecurity: %3\nFrequency: %4 Mhz",
+                                              accessPoint->ssid(),
+                                              network->signalStrength(),
+                                              UiUtils::labelFromWirelessSecurity(security),
+                                              accessPoint->frequency());
                     addItem(QIcon::fromTheme("object-locked"), text, accessPoint->ssid());
                 } else {
-                    const QString text = i18n("%1 (%2%)\nSecurity: Insecure\nFrequency: %3 Mhz", accessPoint->ssid(), network->signalStrength(), accessPoint->frequency());
+                    const QString text =
+                        i18n("%1 (%2%)\nSecurity: Insecure\nFrequency: %3 Mhz", accessPoint->ssid(), network->signalStrength(), accessPoint->frequency());
                     addItem(QIcon::fromTheme("object-unlocked"), text, accessPoint->ssid());
                 }
             }
