@@ -1,21 +1,7 @@
 /*
-    Copyright 2016-2018 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2016-2018 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <htitp://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PLASMA_NM_CREATABLE_CONNECTIONS_MODEL_H
@@ -27,14 +13,16 @@
 
 class Q_DECL_EXPORT CreatableConnectionItem : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    explicit CreatableConnectionItem(const QString &typeName, const QString &typeSection,             // Visible properties
-                                     const QString &description, const QString &icon,                 // Visible properties
-                                     NetworkManager::ConnectionSettings::ConnectionType type,         // Properties needed for creating
-                                     const QString &vpnType = QString(),                              // Properties needed for creating
-                                     const QString &specificType = QString(),                         // Properties needed for creating
-                                     bool shared = false,                                             // Properties needed for creating
+    explicit CreatableConnectionItem(const QString &typeName,
+                                     const QString &typeSection, // Visible properties
+                                     const QString &description,
+                                     const QString &icon, // Visible properties
+                                     NetworkManager::ConnectionSettings::ConnectionType type, // Properties needed for creating
+                                     const QString &vpnType = QString(), // Properties needed for creating
+                                     const QString &specificType = QString(), // Properties needed for creating
+                                     bool shared = false, // Properties needed for creating
                                      QObject *parent = nullptr);
     explicit CreatableConnectionItem(QObject *parent = nullptr);
     ~CreatableConnectionItem() override;
@@ -74,10 +62,9 @@ private:
     QString m_vpnType;
 };
 
-
 class Q_DECL_EXPORT CreatableConnectionsModel : public QAbstractListModel
 {
-Q_OBJECT
+    Q_OBJECT
 public:
     explicit CreatableConnectionsModel(QObject *parent = nullptr);
     ~CreatableConnectionsModel() override;
@@ -88,18 +75,17 @@ public:
         ConnectionSpeficType,
         ConnectionShared,
         ConnectionType,
-        ConnectionTypeName ,
+        ConnectionTypeName,
         ConnectionTypeSection,
-        ConnectionVpnType
+        ConnectionVpnType,
     };
 
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
-    QHash< int, QByteArray > roleNames() const override;
+    QHash<int, QByteArray> roleNames() const override;
 
 private:
-    QList<CreatableConnectionItem*> m_list;
+    QList<CreatableConnectionItem *> m_list;
 };
 
 #endif // PLASMA_NM_CREATABLE_CONNECTIONS_MODEL_H
-
