@@ -1,21 +1,7 @@
 /*
-    Copyright 2013-2018 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013-2018 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PLASMA_NM_MODEL_NETWORK_MODEL_ITEM_H
@@ -31,9 +17,8 @@
 
 class Q_DECL_EXPORT NetworkModelItem : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-
     enum ItemType { UnavailableConnection, AvailableConnection, AvailableAccessPoint };
 
     explicit NetworkModelItem(QObject *parent = nullptr);
@@ -63,7 +48,10 @@ public:
     bool duplicate() const;
 
     void setIcon(const QString &icon);
-    QString icon() const { return m_icon; }
+    QString icon() const
+    {
+        return m_icon;
+    }
 
     ItemType itemType() const;
 
@@ -117,8 +105,14 @@ public:
 
     bool operator==(const NetworkModelItem *item) const;
 
-    QVector<int> changedRoles() const { return m_changedRoles; }
-    void clearChangedRoles() { m_changedRoles.clear(); }
+    QVector<int> changedRoles() const
+    {
+        return m_changedRoles;
+    }
+    void clearChangedRoles()
+    {
+        m_changedRoles.clear();
+    }
 
 public Q_SLOTS:
     void invalidateDetails();
